﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using System.Collections.ObjectModel;
using DlhSoft.Windows.Data;

namespace ScheduleChartResourceListViewManagerSourceSample
{
    /// <summary>
    /// Interaction logic for Window1.xaml
    /// </summary>
    public partial class Window1 : Window
    {
        public Window1()
        {
            InitializeComponent();

            // Prepare the resource data collection.
            ObservableCollection<ResourceItem> resourceItems = new ObservableCollection<ResourceItem>
            {
                new ResourceItem { Content = "Resource 1", CostPerUsage = 100, CostPerHour = 10 },
                new ResourceItem { Content = "Resource 2", CostPerHour = 20 },
                new ResourceItem { Content = "Resource 3", CostPerHour = 20 }
            };

            // Prepare the assignable task data collection.
            ObservableCollection<TaskItem> assignableTaskItems = new ObservableCollection<TaskItem>
            {
                new TaskItem { Content = "Task 1", IndexString = "1" },
                new TaskItem { Content = "Task 1.1", Indentation = 1, Start = DateTime.Today, Effort = TimeSpan.Parse("08:00:00"), CompletedEffort = TimeSpan.Parse("04:00:00"), IndexString = "2" },
                new TaskItem { Content = "Task 1.2", Indentation = 1, IndexString = "3" },
                new TaskItem { Content = "Task 1.2.1", Indentation = 2, Start = DateTime.Today, Effort = TimeSpan.Parse("08:00:00"), IndexString = "4" },
                new TaskItem { Content = "Task 1.2.2", Indentation = 2, Start = DateTime.Today, Effort = TimeSpan.Parse("16:00:00"), IndexString = "5" },
                new TaskItem { Content = "Task 2", IndexString = "6" },
                new TaskItem { Content = "Task 2.1", Indentation = 1, Start = DateTime.Today, Effort = TimeSpan.Parse("16:00:00"), IsCompleted = true, IndexString = "7" },
                new TaskItem { Content = "Task 2.2", Indentation = 1, Start = DateTime.Today, Effort = TimeSpan.Parse("08:00:00"), CompletedEffort = TimeSpan.Parse("06:00:00"), IndexString = "8" },
                new TaskItem { Content = "Task 2.3", Indentation = 1, IndexString = "9", PredecessorsString = "8" },
                new TaskItem { Content = "Task 2.3.1", Indentation = 2, Start = DateTime.Today, Effort = TimeSpan.Parse("1.16:00:00"), IndexString = "10", Cost = 2000 },
                new TaskItem { Content = "Task 2.3.2", Indentation = 2, Start = DateTime.Today, Effort = TimeSpan.Parse("08:00:00"), IndexString = "11", PredecessorsString = "10" },
                new TaskItem { Content = "Task 3", Start = DateTime.Today, Effort = TimeSpan.Parse("12:30:00"), CompletedEffort = TimeSpan.Parse("02:30:00"), IndexString = "12", PredecessorsString = "9, 11SS+12" },
                new TaskItem { Content = "Task 4", Start = DateTime.Today, Effort = TimeSpan.Parse("16:00:00"), AssignmentsString = "Resource 1", IndexString = "13" },
                new TaskItem { Content = "Task 5", Start = DateTime.Today, Effort = TimeSpan.Parse("20:00:00"), AssignmentsString = "Resource 1, Resource 2 [50%]", IndexString = "14" },
                new TaskItem { Content = "Task 6", Start = DateTime.Today, IsMilestone = true, IndexString = "15", PredecessorsString = "14+2" },
                new TaskItem { Content = "Task 7", Start = DateTime.Today, Effort = TimeSpan.Parse("16:00:00"), CompletedEffort = TimeSpan.Parse("08:00:00"), AssignmentsString = "Resource 1", IndexString = "16", PredecessorsString = "15+2" },
                new TaskItem { Content = "Task 8", Start = DateTime.Today, Effort = TimeSpan.Parse("16:00:00"), AssignmentsString = "Resource 1", IndexString = "17", PredecessorsString = "16" },
                new TaskItem { Content = "Task 9", Start = DateTime.Today, Effort = TimeSpan.Parse("16:00:00"), AssignmentsString = "Resource 2", IndexString = "18", PredecessorsString = "16" },
                new TaskItem { Content = "Task 10", Start = DateTime.Today, Effort = TimeSpan.Parse("16:00:00"), AssignmentsString = "Resource 2, Resource 3 [75%]", IndexString = "19", PredecessorsString = "18" }
            };

            // Prepare the resource manager.
            ResourceManager resourceManager = new ResourceManager(resourceItems);

            // Prepare the assignable task manager.
            TaskManager assignableTaskManager = new TaskManager(assignableTaskItems, resourceManager, Schedule.Standard);

            // Set the TaskManagerSource to the prepared task manager instance.
            ScheduleChartResourceListView.TaskManagerSource = assignableTaskManager;

            // You could set the TaskManagerSource of another control to the same task manager instance in order to reuse the business logic component managing the specified task data collection and/or increase performance.
            // AnotherControl.TaskManagerSource = taskManager;
        }
    }
}
